Glossary
--------

.. glossary::

    Counter
      A variable used to count something. It's usually initialized to zero and then incremented.

    Empty String
      A string with no characters and length 0, represented by two quotation marks.

    Format Operator
      An operator, ``%``, that takes a format string and a tuple and generates a string that includes the elements of the tuple formatted as specified by the format string.

    Format Sequence
      A sequence of characters in a format string, like ``%d``, that specifies how a value should be formatted.

    Format String
      A string, used with the format operator, that contains format sequences.

    Flag
      A boolean variable used to indicate whether a condition is true or false.

    Invocation
      A statement that calls a method.

    Immutable
      A property of sequences whose items cannot be reassigned.

    String Index
      An integer value used to select a character in a string.

    Item
      One of the values in a sequence.

    Method
      A function that is associated with an object and called using dot notation.

    String Object
      A string that a variable can refer to. For now, you can use "object" and "value" interchangeably.

    Search
      A pattern of traversal that stops when it finds what it is looking for.

    Sequence
      An ordered set; that is, a set of values where each value is identified by an integer index.

    Slice
      A part of a string specified by a range of indicies.

    Traverse
      To iterate through the items in a sequence, performing a similar operation on each.


.. dragndrop:: str-glossary1
      :feedback: Look above for the definitions of these terms.
      :match_1: counter|||A variable used to count something. It's usually initialized to zero and then incremented.
      :match_2: empty string|||A string with no characters and length 0, represented by two quotation marks.
      :match_3: index|||An integer value used to select an item in a sequence, such as a character in a string.
      :match_4: string object|||A string that a variable can refer to.

      Match each term with its definition.

.. dragndrop:: str-glossary2
    :feedback: Look above for the definitions of these terms.
    :match_1: format operator|||An operator, ``%``, that takes a format string and a tuple and generates a string that includes the elements of the tuple formatted as specified by the format string.
    :match_2: format sequence|||A sequence of characters in a format string, like ``%d``, that specifies how a value should be formatted.
    :match_3: format string|||A string, used with the format operator, that contains format sequences.
    :match_4: sequence|||An ordered set; that is, a set of values where each value is identified by an integer index.

    Match each term with its definition.

.. dragndrop:: str-glossary3
    :feedback: Look above for the definitions of these terms.
    :match_1: flag|||A boolean variable used to indicate whether a condition is true or false.
    :match_2: invocation|||A statement that calls a method.
    :match_3: item|||One of the values in a sequence.
    :match_4: slice|||A part of a string specified by a range of indices.

    Match each term with its definition.

.. dragndrop:: str-glossary4
    :feedback: Look above for the definitions of these terms.
    :match_1: immutable||| A property of sequences whose items cannot be reassigned.
    :match_2: method|||A function that is associated with an object and called using dot notation.
    :match_3: search|||A pattern of traversal that stops when it finds what it is looking for.
    :match_4: traverse|||To iterate through the items in a sequence, performing a similar operation on each.

    Match each term with its definition.
